@@ -17,21 +17,24 @@ import copy
 import json
 import re
 
-from django.core.urlresolvers import reverse
 from django.core import validators as django_validator
 from django import forms
 from django.forms import widgets
 from django.template import defaultfilters
+from django.urls import reverse
 from django.utils.encoding import force_text
 from django.utils import html
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms as hz_forms
 from horizon import messages
+try:
+    from openstack_dashboard.api import _nova as nova
+except ImportError:
+    from openstack_dashboard.api import nova
 from openstack_dashboard.api import cinder
 from openstack_dashboard.api import glance
 from openstack_dashboard.api import neutron
-from openstack_dashboard.api import nova
 from oslo_log import log as logging
 from oslo_log import versionutils
 import six
